var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import * as V from 'victory';
import { VictoryLine, VictoryChart, VictoryAxis, VictoryTheme, VictoryLabel } from 'victory';
//import axios from 'axios'
import moment from 'moment';

var BLUE_COLOR = '#00a3de';
var RED_COLOR = '#7c270b';
var ORANGES = ['#ed6930', '#e85c34', '#e15035', '#da4134', '#d53239', '#cf1339', '#c8003b', '#c8003b', '#bb003c', '#aa003c'];
var LEGEND_FONT_SIZE = 12;
var styles = {
  parent: {
    //background: '#ccdee8',
    boxSizing: 'border-box',

    display: 'inline',
    padding: 10,
    fontFamily: '"Fira Sans", sans-serif',
    maxWidth: '50%',
    height: 'auto'
  },
  title: {
    textAnchor: 'start',
    verticalAnchor: 'end',
    fill: '#727272',
    fontFamily: 'inherit',
    fontSize: '15px',
    fontWeight: 'bold'
  },
  labelNumber: {
    textAnchor: 'middle',
    fill: '#727272',
    fontFamily: 'inherit',
    fontSize: '14px'
  },

  legend: {
    fill: 'white',
    fontSize: LEGEND_FONT_SIZE
  },

  // INDEPENDENT AXIS

  maxLine: {
    data: { stroke: RED_COLOR, strokeWidth: 50 }
  },
  dataLine: {
    data: { stroke: '#FFF', strokeWidth: 2 }
  },
  effortLine: {
    data: { stroke: '#000', strokeWidth: 1, strokeDasharray: 2 }
  },
  axisPrincipal: {
    axis: {
      fill: '#727272'
    },
    tickLabels: {
      fill: '#727272',
      fontSize: 12,
      fontWeight: 'bold'
    }

  },
  labelData: {
    fontWeight: 'bold',
    fill: '#727272',
    fontSize: 12
  },
  labelValue: {
    fontSize: 12,
    fill: '#727272'
  }
};

var getHeartsByEffort = function getHeartsByEffort(eff, max, min) {
  return (max - min) * eff / 100 + min;
};
var getTimeTicks = function getTimeTicks(data) {
  var size = 60 * 10; //10 min
  var totalTicks = Math.ceil(data.length / size);
  var ticks = [];
  for (var i = 0; i < totalTicks; i++) {
    ticks.push(i * size);
  }
  return ticks;
};

var getMinutesFormatted = function getMinutesFormatted(segs) {
  var mins = Math.floor(segs / 60);
  var seg = Math.ceil(segs % 60 / 10);
  return seg ? mins + '.' + seg : mins;
};

var SessionResult = function (_Component) {
  _inherits(SessionResult, _Component);

  function SessionResult(props) {
    _classCallCheck(this, SessionResult);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  SessionResult.prototype.getFormattedSession = function getFormattedSession() {
    var _props = this.props,
        dateSession = _props.dateSession,
        points = _props.points,
        currentData = _props.currentData,
        maxHeartbeat = _props.maxHeartbeat,
        minHeartbeat = _props.minHeartbeat,
        nick = _props.nick,
        avatarUrl = _props.avatarUrl;

    var y90 = getHeartsByEffort(90, maxHeartbeat, minHeartbeat);
    var y80 = getHeartsByEffort(80, maxHeartbeat, minHeartbeat);
    var y70 = getHeartsByEffort(70, maxHeartbeat, minHeartbeat);
    var y60 = getHeartsByEffort(60, maxHeartbeat, minHeartbeat);
    var lastValid = 0;

    var _currentData$reduce = currentData.reduce(function (all, curr, index) {
      lastValid = curr > 40 ? curr : lastValid;
      all.data.push({
        x: index,
        y: !curr || curr < 40 ? lastValid : curr
      });
      if (index === currentData.length - 1 || index === 0) {
        all.e90.push({ x: index, y: y90 });
        all.e80.push({ x: index, y: y80 });
        all.e70.push({ x: index, y: y70 });
        all.e60.push({ x: index, y: y60 });
      }
      if (curr < y60) {
        all.timeUnder60 += 1;
      } else if (curr < y70) {
        all.time60to70 += 1;
      } else if (curr < y80) {
        all.time70to80 += 1;
      } else if (curr < y90) {
        all.time80to90 += 1;
      } else {
        all.time90toMore += 1;
      }
      return all;
    }, {
      data: [],
      e80: [],
      e90: [],
      e70: [],
      e60: [],
      time90toMore: 0,
      time80to90: 0,
      time70to80: 0,
      time60to70: 0,
      timeUnder60: 0
    }),
        data = _currentData$reduce.data,
        e90 = _currentData$reduce.e90,
        e80 = _currentData$reduce.e80,
        e70 = _currentData$reduce.e70,
        e60 = _currentData$reduce.e60,
        time90toMore = _currentData$reduce.time90toMore,
        time80to90 = _currentData$reduce.time80to90,
        time70to80 = _currentData$reduce.time70to80,
        time60to70 = _currentData$reduce.time60to70,
        timeUnder60 = _currentData$reduce.timeUnder60;

    return {
      dateSession: dateSession,
      points: points,
      data: data,
      e90: e90,
      e80: e80,
      e70: e70,
      e60: e60,
      max: maxHeartbeat,
      basal: minHeartbeat,
      avatarUrl: avatarUrl,
      nick: nick,
      time90toMore: time90toMore,
      time80to90: time80to90,
      time70to80: time70to80,
      time60to70: time60to70,
      timeUnder60: timeUnder60
    };
  };

  SessionResult.prototype.render = function render() {
    var width = 800;
    var marginWidth = 100;
    var height = 350;
    var marginHeight = 100;

    var _getFormattedSession = this.getFormattedSession(),
        dateSession = _getFormattedSession.dateSession,
        points = _getFormattedSession.points,
        data = _getFormattedSession.data,
        e90 = _getFormattedSession.e90,
        e80 = _getFormattedSession.e80,
        e70 = _getFormattedSession.e70,
        e60 = _getFormattedSession.e60,
        max = _getFormattedSession.max,
        basal = _getFormattedSession.basal,
        avatarUrl = _getFormattedSession.avatarUrl,
        nick = _getFormattedSession.nick,
        time90toMore = _getFormattedSession.time90toMore,
        time80to90 = _getFormattedSession.time80to90,
        time70to80 = _getFormattedSession.time70to80,
        time60to70 = _getFormattedSession.time60to70,
        timeUnder60 = _getFormattedSession.timeUnder60;

    var axisY = [basal - 8, max + 8];
    var ticksEffort = [60, 70, 80, 90];
    var _props2 = this.props,
        id = _props2.id,
        calories = _props2.calories,
        customLeftPadding = _props2.customLeftPadding;

    return React.createElement(
      'svg',
      { id: id, style: styles.parent, width: width, height: height + marginHeight + 120, viewBox: '0 0 ' + width + ' ' + (height + marginHeight + 120),
        key: dateSession
      },
      React.createElement('rect', { x: width - marginWidth / 2, y: marginHeight / 4, width: marginHeight / 2, height: marginHeight / 4, fill: '#727272' }),
      React.createElement('rect', { x: 0, y: marginHeight / 4, width: marginHeight / 2, height: marginHeight / 4, fill: '#727272' }),
      React.createElement(VictoryLabel, { x: marginWidth / 2, y: 25, style: styles.title,
        text: moment(dateSession).format('DD/MM/YYYY HH:mm') + '. ' + nick + ' DEP: ' + points
      }),
      React.createElement(VictoryLabel, { x: width - marginWidth / 2 + 10, y: marginHeight / 4 + LEGEND_FONT_SIZE, style: styles.legend,
        text: 'EFF%'
      }),
      React.createElement(VictoryLabel, { x: 10, y: marginHeight / 4 + LEGEND_FONT_SIZE, width: marginHeight / 2, style: styles.legend,
        text: 'PPM'
      }),
      ORANGES.map(function (o, i) {
        return React.createElement('rect', {
          key: i,
          x: marginWidth / 2,
          y: marginHeight / 2 + height / 10 * i,
          width: width - marginWidth,
          height: height / 10,
          fill: o });
      }),
      React.createElement(VictoryAxis, {
        width: width,
        height: height,
        offsetY: -marginHeight / 2,
        domain: [0, data.length],
        standalone: false,
        tickValues: getTimeTicks(data),
        tickFormat: function tickFormat(t) {
          return Math.floor(t / 60) + '\'';
        },
        style: styles.axisPrincipal
      }),
      React.createElement(VictoryAxis, { dependentAxis: true,
        width: width
        //padding={{ left: 30 }}
        , offsetX: marginWidth / 2,
        orientation: 'left',
        height: height + marginHeight,
        domain: axisY,
        standalone: false,
        style: _extends({}, styles.axisPrincipal, { tickLabels: _extends({}, styles.axisPrincipal.tickLabels, { padding: customLeftPadding || 0 }) })
      }),
      React.createElement(VictoryAxis, { dependentAxis: true,
        width: width,
        offsetX: marginWidth / 2,
        orientation: 'right',
        height: height + marginHeight,
        domain: axisY,
        standalone: false,
        tickValues: [e60[0].y, e70[0].y, e80[0].y, e90[0].y],
        tickFormat: function tickFormat(t, i) {
          return ticksEffort[i] + '%';
        },
        style: styles.axisPrincipal
      }),
      React.createElement(VictoryLine, {
        data: data,
        width: width,
        height: height + marginHeight,
        domain: { x: [0, data.length], y: axisY }
        //scale={{x: "time", y: "linear"}}
        , standalone: false,
        style: styles.dataLine
      }),
      React.createElement(VictoryLine, {
        data: e90,
        width: width,
        height: height + marginHeight,
        domain: { x: [0, data.length], y: axisY }
        //scale={{x: "time", y: "linear"}}
        , standalone: false,
        style: styles.effortLine
      }),
      React.createElement(VictoryLine, {
        data: e80,
        width: width,
        height: height + marginHeight,
        domain: { x: [0, data.length], y: axisY }
        //scale={{x: "time", y: "linear"}}
        , standalone: false,
        style: styles.effortLine
      }),
      React.createElement(VictoryLine, {
        data: e70,
        width: width,
        height: height + marginHeight,
        domain: { x: [0, data.length], y: axisY }
        //scale={{x: "time", y: "linear"}}
        , standalone: false,
        style: styles.effortLine
      }),
      React.createElement(VictoryLine, {
        data: e60,
        width: width,
        height: height + marginHeight,
        domain: { x: [0, data.length], y: axisY }
        //scale={{x: "time", y: "linear"}}
        , standalone: false,
        style: styles.effortLine
      }),
      React.createElement(
        'text',
        { style: styles.labelData, x: '30', y: height + marginHeight + 10 },
        'Tiempo a m\xE1s de 90% esfuerzo:'
      ),
      React.createElement(
        'text',
        { style: styles.labelValue, x: '300', y: height + marginHeight + 10 },
        ' ',
        getMinutesFormatted(time90toMore),
        'min (el ',
        Math.round(time90toMore * 10000 / data.length) / 100,
        '% del entrenamiento)'
      ),
      React.createElement(
        'text',
        { style: styles.labelData, x: '30', y: height + marginHeight + 30 },
        'Tiempo entre 80% y 90% de esfuerzo:'
      ),
      React.createElement(
        'text',
        { style: styles.labelValue, x: '300', y: height + marginHeight + 30 },
        ' ',
        getMinutesFormatted(time80to90),
        'min (el ',
        Math.round(time80to90 * 10000 / data.length) / 100,
        '% del entrenamiento)'
      ),
      React.createElement(
        'text',
        { style: styles.labelData, x: '30', y: height + marginHeight + 50 },
        'Tiempo entre 70% y 80% de esfuerzo:'
      ),
      React.createElement(
        'text',
        { style: styles.labelValue, x: '300', y: height + marginHeight + 50 },
        ' ',
        getMinutesFormatted(time70to80),
        'min (el ',
        Math.round(time70to80 * 10000 / data.length) / 100,
        '% del entrenamiento)'
      ),
      React.createElement(
        'text',
        { style: styles.labelData, x: '30', y: height + marginHeight + 70 },
        'Tiempo entre 60% y 70% de esfuerzo:'
      ),
      React.createElement(
        'text',
        { style: styles.labelValue, x: '300', y: height + marginHeight + 70 },
        ' ',
        getMinutesFormatted(time60to70),
        'min (el ',
        Math.round(time60to70 * 10000 / data.length) / 100,
        '% del entrenamiento)'
      ),
      React.createElement(
        'text',
        { style: styles.labelData, x: '30', y: height + marginHeight + 90 },
        'Tiempo a menos de 60% esfuerzo:'
      ),
      React.createElement(
        'text',
        { style: styles.labelValue, x: '300', y: height + marginHeight + 90 },
        ' ',
        getMinutesFormatted(timeUnder60),
        'min (el ',
        Math.round(timeUnder60 * 10000 / data.length) / 100,
        '% del entrenamiento)'
      ),
      React.createElement(
        'text',
        { style: styles.labelData, x: '30', y: height + marginHeight + 110 },
        'Calorias:'
      ),
      React.createElement(
        'text',
        { style: styles.labelValue, x: '300', y: height + marginHeight + 110 },
        ' ',
        calories
      )
    );
  };

  return SessionResult;
}(Component);

export default SessionResult;